@@ -33,7 +33,7 @@
 #define MAX_CHIP_NAMES 32
 
 int isDaemon = 0;
-const char *sensorsCfgFile = "sensors.conf";
+const char *sensorsCfgFile = NULL;
 const char *pidFile = "/var/run/sensord.pid";
 const char *rrdFile = NULL;
 const char *cgiDir = NULL;
@@ -102,7 +102,7 @@ static const char *daemonSyntax =
   "  -t, --rrd-interval <time> -- interval between updating RRD file (default 5m)\n"
   "  -T, --rrd-no-average      -- switch RRD in non-average mode\n"
   "  -r, --rrd-file <file>     -- RRD file (default <none>)\n"
-  "  -c, --config-file <file>  -- configuration file (default sensors.conf)\n"
+  "  -c, --config-file <file>  -- configuration file\n"
   "  -p, --pid-file <file>     -- PID file (default /var/run/sensord.pid)\n"
   "  -f, --syslog-facility <f> -- syslog facility to use (default local4)\n"
   "  -g, --rrd-cgi <img-dir>   -- output an RRD CGI script and exit\n"
@@ -114,8 +114,7 @@ static const char *daemonSyntax =
   "Specify a value of 0 for any interval to disable that operation;\n"
   "for example, specify --log-interval 0 to only scan for alarms."
   "\n"
-  "If no path is specified, a list of directories is examined for the config file;\n"
-  "specify the filename `-' to read the config file from stdin.\n"
+  "Specify the filename `-' to read the config file from stdin.\n"
   "\n"
   "If no chips are specified, all chip info will be printed.\n"
   "\n"
@@ -128,13 +127,12 @@ static const char *appSyntax =
   "  -a, --alarm-scan          -- only scan for alarms\n"
   "  -s, --set                 -- execute set statements (root only)\n"
   "  -r, --rrd-file <file>     -- only update RRD file\n"
-  "  -c, --config-file <file>  -- configuration file (default sensors.conf)\n"
+  "  -c, --config-file <file>  -- configuration file\n"
   "  -d, --debug               -- display some debug information\n"
   "  -v, --version             -- display version and exit\n"
   "  -h, --help                -- display help and exit\n"
   "\n"
-  "If no path is specified, a list of directories is examined for the config file;\n"
-  "specify the filename `-' to read the config file from stdin.\n"
+  "Specify the filename `-' to read the config file from stdin.\n"
   "\n"
   "If no chips are specified, all chip info will be printed.\n";
 
@@ -285,7 +283,8 @@ parseChips
 (int argc, char **argv) {
   if (optind == argc) {
     chipNames[0].prefix = SENSORS_CHIP_NAME_PREFIX_ANY;
-    chipNames[0].bus = SENSORS_CHIP_NAME_BUS_ANY;
+    chipNames[0].bus.type = SENSORS_BUS_TYPE_ANY;
+    chipNames[0].bus.nr = SENSORS_BUS_NR_ANY;
     chipNames[0].addr = SENSORS_CHIP_NAME_ADDR_ANY;
     numChipNames = 1;
   } else {
