@@ -139,41 +139,36 @@ applyToFeatures
   const sensors_chip_name *chip;
   int i = 0, j, ret = 0, num = 0;
 
-  while ((ret == 0) && ((chip = sensors_get_detected_chips (&i)) != NULL)) {
-    for (j = 0; (ret == 0) && (j < numChipNames); ++ j) {
-      if (sensors_match_chip (*chip, chipNames[j])) {
-        int index0, subindex, chipindex = -1;
-        for (index0 = 0; knownChips[index0]; ++ index0)
-          for (subindex = 0; knownChips[index0]->names[subindex]; ++ subindex)
-            if (!strcmp (chip->prefix, knownChips[index0]->names[subindex]))
-              chipindex = index0;
-        if (chipindex >= 0) {
-          const ChipDescriptor *descriptor = knownChips[chipindex];
-          const FeatureDescriptor *features = descriptor->features;
+  for (j = 0; (ret == 0) && (j < numChipNames); ++ j) {
+    while ((ret == 0) && ((chip = sensors_get_detected_chips (&chipNames[j], &i)) != NULL)) {
+      int index0, chipindex = -1;
+      for (index0 = 0; knownChips[index0].features; ++ index0)
+        /* Trick: we compare addresses here. We know it works because both
+           pointers were returned by sensors_get_detected_chips(), so they
+           refer to libsensors internal structures, which do not move. */
+        if (knownChips[index0].name == chip) {
+          chipindex = index0;
+          break;
+        }
+      if (chipindex >= 0) {
+        const ChipDescriptor *descriptor = &knownChips[chipindex];
+        const FeatureDescriptor *features = descriptor->features;
 
-          for (index0 = 0; (ret == 0) && (num < MAX_RRD_SENSORS) && features[index0].format; ++ index0) {
-            const FeatureDescriptor *feature = features + index0;
-            int labelNumber = feature->dataNumbers[0];
-            const char *rawLabel = NULL;
-            char *label = NULL;
-            int valid = 0;
-            if (getValid (*chip, labelNumber, &valid)) {
-              sensorLog (LOG_ERR, "Error getting sensor validity: %s/#%d", chip->prefix, labelNumber);
-              ret = -1;
-            } else if (getRawLabel (*chip, labelNumber, &rawLabel)) {
-              sensorLog (LOG_ERR, "Error getting raw sensor label: %s/#%d", chip->prefix, labelNumber);
-              ret = -1;
-            } else if (getLabel (*chip, labelNumber, &label)) {
-              sensorLog (LOG_ERR, "Error getting sensor label: %s/#%d", chip->prefix, labelNumber);
-              ret = -1;
-            } else if (valid) {
-              rrdCheckLabel (rawLabel, num);
-              ret = fn (data, rrdLabels[num], label, feature);
-              ++ num;
-            }
-            if (label)
-              free (label);
+        for (index0 = 0; (ret == 0) && (num < MAX_RRD_SENSORS) && features[index0].format; ++ index0) {
+          const FeatureDescriptor *feature = features + index0;
+          const char *rawLabel = features->feature->name;
+          char *label = NULL;
+
+          if (!(label = sensors_get_label (chip, features->feature))) {
+            sensorLog (LOG_ERR, "Error getting sensor label: %s/%s", chip->prefix, rawLabel);
+            ret = -1;
+          } else  {
+            rrdCheckLabel (rawLabel, num);
+            ret = fn (data, rrdLabels[num], label, feature);
+            ++ num;
           }
+          if (label)
+            free (label);
         }
       }
     }
@@ -190,6 +185,7 @@ struct ds {
 static int
 rrdGetSensors_DS
 (void *_data, const char *rawLabel, const char *label, const FeatureDescriptor *feature) {
+  (void) label; /* no warning */
   if (!feature || feature->rrd) {
     struct ds *data = (struct ds *) _data;
     char *ptr = rrdBuff + data->num * RRD_BUFF;
@@ -205,12 +201,8 @@ rrdGetSensors_DS
         max = "12000";
         break;
       case DataType_temperature:
-        min = "-100";
-        max = "250";
-        break;
-      case DataType_mhz:
         min = "0";
-        max = "U";
+        max = "250";
         break;
       default:
         min = max = "U";
@@ -296,6 +288,7 @@ static int
 rrdCGI_DEF
 (void *_data, const char *rawLabel, const char *label, const FeatureDescriptor *feature) {
   struct gr *data = (struct gr *) _data;
+  (void) label; /* no warning */
   if (!feature || (feature->rrd && (feature->type == data->type)))
     printf ("\n\tDEF:%s=%s:%s:AVERAGE", rawLabel, rrdFile, rawLabel);
   return 0;
